==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/AWSClusterDeprovisionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AWSClusterDeprovisionBuilder extends AWSClusterDeprovisionFluentImpl<AWSClusterDeprovisionBuilder> implements VisitableBuilder<AWSClusterDeprovision,AWSClusterDeprovisionBuilder>{
  public AWSClusterDeprovisionBuilder() {
    this(false);
  }
  public AWSClusterDeprovisionBuilder(Boolean validationEnabled) {
    this(new AWSClusterDeprovision(), validationEnabled);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovisionFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AWSClusterDeprovision(), validationEnabled);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovisionFluent<?> fluent,AWSClusterDeprovision instance) {
    this(fluent, instance, false);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovisionFluent<?> fluent,AWSClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCredentialsAssumeRole(instance.getCredentialsAssumeRole());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withRegion(instance.getRegion());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovision instance) {
    this(instance,false);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCredentialsAssumeRole(instance.getCredentialsAssumeRole());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withRegion(instance.getRegion());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AWSClusterDeprovisionFluent<?> fluent;
  Boolean validationEnabled;
  public AWSClusterDeprovision build() {
    AWSClusterDeprovision buildable = new AWSClusterDeprovision(fluent.getCredentialsAssumeRole(),fluent.getCredentialsSecretRef(),fluent.getRegion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/AWSClusterDeprovisionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AWSClusterDeprovisionBuilder extends AWSClusterDeprovisionFluent<AWSClusterDeprovisionBuilder> implements VisitableBuilder<AWSClusterDeprovision,AWSClusterDeprovisionBuilder>{
  public AWSClusterDeprovisionBuilder() {
    this(false);
  }
  public AWSClusterDeprovisionBuilder(Boolean validationEnabled) {
    this(new AWSClusterDeprovision(), validationEnabled);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovisionFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AWSClusterDeprovision(), validationEnabled);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovisionFluent<?> fluent,AWSClusterDeprovision instance) {
    this(fluent, instance, false);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovisionFluent<?> fluent,AWSClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new AWSClusterDeprovision());

    if (instance != null) {
      fluent.withCredentialsAssumeRole(instance.getCredentialsAssumeRole());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withRegion(instance.getRegion());
      fluent.withCredentialsAssumeRole(instance.getCredentialsAssumeRole());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withRegion(instance.getRegion());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovision instance) {
    this(instance,false);
  }
  public AWSClusterDeprovisionBuilder(AWSClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new AWSClusterDeprovision());

    if (instance != null) {
      this.withCredentialsAssumeRole(instance.getCredentialsAssumeRole());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withRegion(instance.getRegion());
      this.withCredentialsAssumeRole(instance.getCredentialsAssumeRole());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withRegion(instance.getRegion());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AWSClusterDeprovisionFluent<?> fluent;
  Boolean validationEnabled;
  public AWSClusterDeprovision build() {
    AWSClusterDeprovision buildable = new AWSClusterDeprovision(fluent.buildCredentialsAssumeRole(),fluent.buildCredentialsSecretRef(),fluent.getRegion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
